generate.cate.list: Generate (NxJ) categorical data matrix.
Description
Generate an (NxJ) categorical data matrix given by prop.J.list and true cluster allocation.
Usage
generate.cate.list(N = N, prop.list = prop.list)
Value
an (NxJ) categorical data matrix.
Arguments
- N
The number of observations.
- prop.list
a list length J, each of which is a vector of length qj giving the proportion for each categories.