Generate an (NxJ) clustered categorical data matrix given by prop.J.list and true cluster allocation.
generate.catecls(
N = N,
J = J,
q.vec = q.vec,
Ktrue = Ktrue,
prop.J.list = prop.J.list,
clstr.vec = clstr.vec
)an (NxJ) clustered categorical data matrix.
The number of observations.
The number of active variables.
A vector of length J giving the number of categories for each active variable.
An integer indicating the number of content-based clusters used for CCRS estimation.
a list of length J, where each list is a (Ktrue x qj) matrix giving the proportion for each qj category in each of the Ktrue cluster.
A vector of length N giving true clusters for each observations.